/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2023 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp23nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp23nid ;

DATA library.&dataset ;
INFILE datafile LRECL=4607;
INPUT
   ACCEPT  1-3              BUSCLAS  4-7             CANTPAY  8-10         
   CCULPSCO  11-13          CH2APP  14-16            CH8FINGD  17-19       
   CMSRVORD  20-22          COFI  23-25              COMPLY  26-28         
   COMPLYPR  29-31          CRIMPURP  32-34          DETBFINE  35-37       
   DISPOSIT  38-40          EMPLOYNM  41-43          FCULPSCO  44-46       
   FRAUDTYP  47-49          FINSTDS  50-52           HISTORY  53-55        
   HSMISCND  56-58          INCORLOC  59-61          INCORPYR  62-65       
   INDICT  66-68            INPLEA1  69-71           INPLEA2  72-74        
   INPLEA3  75-77           INPLEA4  78-80           INPLEA5  81-83        
   INPLEA6  84-86           INPLEA7  87-89           INPLEA8  90-92        
   INPLEA9  93-95           INPLEA10  96-98          INPLEA11  99-101      
   INPLEA12  102-104        INNOPL1  105-107         INNOPL2  108-110      
   INNOPL3  111-113         INNOPL4  114-116         INNOPL5  117-119      
   INNOPL6  120-122         INNOPL7  123-125         INNOPL8  126-128      
   INNOPL9  129-131         INNOPL10  132-134        INNOPL11  135-137     
   INNOPL12  138-140        JANDC  141-143           NEWCNVTN  144-146     
   NOCOMP  147-149          NOCOUNTS  150-152        NOREAVAR  153-155     
   NOUSTAT  156-158         OBSTRUCT  159-161        OFFLVL  162-164       
   ORDERCE  165-167         OWNSTRCT  168-170        PLEA  171-173         
   PRIMOFF  174-176         PRCIVIL  177-179         PRCRIME  180-182      
   PROBATN  183-185         PROBMON  186-188         PSR  189-191          
   QUARTER  192-194         REAS1  195-198           REAS2  199-202        
   REAS3  203-205           REAS4  206-208           REAS5  209-211        
   REASON2  212-214         REASON3  215-217         REASON4  218-220      
   REASONS  221-223         REMEDORD  224-226        SELFREP  227-229      
   SENTRNGE  230-232        TOLERNCE  233-235        TYPEOTHS  236-238     
   VICTNOTE  239-241        VIOLATE  242-244         AMENDYR  245-248      
   SENTYR  249-252          BASEFINE  253-262        COSTASSM  263-270     
   DISGORGE  271-278        FINOFFST  279-287        FORFEITR  288-297     
   GLFINMAX  298-307        GLFINMIN  308-317        STATMIN  318-325      
   STATMAX  326-334         RESTCAT  335-342         FINECAT  343-350      
   SUSFNCAT  351-358        LCAT1  359-366           LCAT2  367-374        
   LCAT3  375-382           LCATHI  383-390          LCATS1  391-398       
   LCATS2  399-406          LCATS3  407-414          LCATSHI  415-422      
   LCATR1  423-430          LCATR2  431-438          LCATR3  439-446       
   LCATRHI  447-454         LCATC1  455-462          LCATC2  463-470       
   LCATC3  471-478          LCATCHI  479-486         LCATU1  487-494       
   LCATU2  495-502          LCATU3  503-510          LCATUHI  511-518      
   CPIDN  519-525           BUSTEXT $ 526            FINSTXT $ 527         
   OWNSTEXT $ 528           PRMONTXT $ 529-614       ORDERTXT $ 615-751    
   TYPEOTTX $ 752-900       MINFINML  901-908        MAXFINML  909-916     
   ADJOFL1  917-919         ADJOFL2  920-922         ADJOFL3  923-925      
   ADJOFLHI  926-928        ADJ_B1  929-931          ADJ_B2  932-934       
   ADJ_B3  935-937          ADJ_BHI  938-940         ADJ_C1  941-943       
   ADJ_C2  944-946          ADJ_C3  947-949          ADJ_CHI  950-952      
   ADJ_D1  953-955          ADJ_D2  956-958          ADJ_D3  959-961       
   ADJ_DHI  962-964         ADJ_E1  965-967          ADJ_E2  968-970       
   ADJ_E3  971-973          ADJ_EHI  974-976         ADJ_F1  977-979       
   ADJ_F2  980-982          ADJ_F3  983-985          ADJ_FHI  986-988      
   ADJ_G1  989-991          ADJ_G2  992-994          ADJ_G3  995-997       
   ADJ_GHI  998-1000        ADJ_H1  1001-1003        ADJ_H2  1004-1006     
   ADJ_H3  1007-1009        ADJ_HHI  1010-1012       ADJ_I1  1013-1015     
   ADJ_I2  1016-1018        ADJ_I3  1019-1021        ADJ_IHI  1022-1024    
   ADJ_J1  1025-1027        ADJ_J2  1028-1030        ADJ_J3  1031-1033     
   ADJ_JHI  1034-1036       ADJ_K1  1037-1039        ADJ_K2  1040-1042     
   ADJ_K3  1043-1045        ADJ_KHI  1046-1048       ADJ_L1  1049-1051     
   ADJ_L2  1052-1054        ADJ_L3  1055-1057        ADJ_LHI  1058-1060    
   ADJ_M1  1061-1063        ADJ_M2  1064-1066        ADJ_M3  1067-1069     
   ADJ_MHI  1070-1072       ADJ_N1  1073-1075        ADJ_N2  1076-1078     
   ADJ_N3  1079-1081        ADJ_NHI  1082-1084       ADJ_O1  1085-1087     
   ADJ_O2  1088-1090        ADJ_O3  1091-1093        ADJ_OHI  1094-1096    
   ADJ_P1  1097-1099        ADJ_P2  1100-1102        ADJ_P3  1103-1105     
   ADJ_PHI  1106-1108       ADJ_Q1  1109-1111        ADJ_Q2  1112-1114     
   ADJ_Q3  1115-1117        ADJ_QHI  1118-1120       ADJ_R1  1121-1123     
   ADJ_R2  1124-1126        ADJ_R3  1127-1129        ADJ_RHI  1130-1132    
   ADJ_S1  1133-1135        ADJ_S2  1136-1138        ADJ_S3  1139-1141     
   ADJ_SHI  1142-1144       ADJ_T1  1145-1147        ADJ_T2  1148-1150     
   ADJ_T3  1151-1153        ADJ_THI  1154-1156       ADJ_U1  1157-1159     
   ADJ_U2  1160-1162        ADJ_U3  1163-1165        ADJ_UHI  1166-1168    
   BASADJ1  1169-1171       BASADJ2  1172-1174       BASADJ3  1175-1177    
   BASADJHI  1178-1180      BASE1  1181-1183         BASE2  1184-1186      
   BASE3  1187-1189         BASEHI  1190-1192        BASLN1  1193-1195     
   BASLN2  1196-1198        BASLN3  1199-1201        BASLNHI  1202-1204    
   ADJOFS1  1205-1207       ADJOFS2  1208-1210       ADJOFS3  1211-1213    
   ADJOFSHI  1214-1216      ADJS_B1  1217-1219       ADJS_B2  1220-1222    
   ADJS_B3  1223-1225       ADJS_BHI  1226-1228      ADJS_C1  1229-1231    
   ADJS_C2  1232-1234       ADJS_C3  1235-1237       ADJS_CHI  1238-1240   
   ADJS_D1  1241-1243       ADJS_D2  1244-1246       ADJS_D3  1247-1249    
   ADJS_DHI  1250-1252      ADJS_E1  1253-1255       ADJS_E2  1256-1258    
   ADJS_E3  1259-1261       ADJS_EHI  1262-1264      ADJS_F1  1265-1267    
   ADJS_F2  1268-1270       ADJS_F3  1271-1273       ADJS_FHI  1274-1276   
   ADJS_G1  1277-1279       ADJS_G2  1280-1282       ADJS_G3  1283-1285    
   ADJS_GHI  1286-1288      ADJS_H1  1289-1291       ADJS_H2  1292-1294    
   ADJS_H3  1295-1297       ADJS_HHI  1298-1300      ADJS_I1  1301-1303    
   ADJS_I2  1304-1306       ADJS_I3  1307-1309       ADJS_IHI  1310-1312   
   ADJS_J1  1313-1315       ADJS_J2  1316-1318       ADJS_J3  1319-1321    
   ADJS_JHI  1322-1324      ADJS_K1  1325-1327       ADJS_K2  1328-1330    
   ADJS_K3  1331-1333       ADJS_KHI  1334-1336      ADJS_L1  1337-1339    
   ADJS_L2  1340-1342       ADJS_L3  1343-1345       ADJS_LHI  1346-1348   
   ADJS_M1  1349-1351       ADJS_M2  1352-1354       ADJS_M3  1355-1357    
   ADJS_MHI  1358-1360      ADJS_N1  1361-1363       ADJS_N2  1364-1366    
   ADJS_N3  1367-1369       ADJS_NHI  1370-1372      ADJS_O1  1373-1375    
   ADJS_O2  1376-1378       ADJS_O3  1379-1381       ADJS_OHI  1382-1384   
   ADJS_P1  1385-1387       ADJS_P2  1388-1390       ADJS_P3  1391-1393    
   ADJS_PHI  1394-1396      ADJS_Q1  1397-1399       ADJS_Q2  1400-1402    
   ADJS_Q3  1403-1405       ADJS_QHI  1406-1408      ADJS_R1  1409-1411    
   ADJS_R2  1412-1414       ADJS_R3  1415-1417       ADJS_RHI  1418-1420   
   ADJS_S1  1421-1423       ADJS_S2  1424-1426       ADJS_S3  1427-1429    
   ADJS_SHI  1430-1432      ADJS_T1  1433-1435       ADJS_T2  1436-1438    
   ADJS_T3  1439-1441       ADJS_THI  1442-1444      ADJS_U1  1445-1447    
   ADJS_U2  1448-1450       ADJS_U3  1451-1453       ADJS_UHI  1454-1456   
   BASADS1  1457-1459       BASADS2  1460-1462       BASADS3  1463-1465    
   BASADSHI  1466-1468      BASES1  1469-1471        BASES2  1472-1474     
   BASES3  1475-1477        BASESHI  1478-1480       BASLNS1  1481-1483    
   BASLNS2  1484-1486       BASLNS3  1487-1489       BASLNSHI  1490-1492   
   ADJOFR1  1493-1495       ADJOFR2  1496-1498       ADJOFR3  1499-1501    
   ADJOFRHI  1502-1504      ADJR_B1  1505-1507       ADJR_B2  1508-1510    
   ADJR_B3  1511-1513       ADJR_BHI  1514-1516      ADJR_C1  1517-1519    
   ADJR_C2  1520-1522       ADJR_C3  1523-1525       ADJR_CHI  1526-1528   
   ADJR_D1  1529-1531       ADJR_D2  1532-1534       ADJR_D3  1535-1537    
   ADJR_DHI  1538-1540      ADJR_E1  1541-1543       ADJR_E2  1544-1546    
   ADJR_E3  1547-1549       ADJR_EHI  1550-1552      ADJR_F1  1553-1555    
   ADJR_F2  1556-1558       ADJR_F3  1559-1561       ADJR_FHI  1562-1564   
   ADJR_G1  1565-1567       ADJR_G2  1568-1570       ADJR_G3  1571-1573    
   ADJR_GHI  1574-1576      ADJR_H1  1577-1579       ADJR_H2  1580-1582    
   ADJR_H3  1583-1585       ADJR_HHI  1586-1588      ADJR_I1  1589-1591    
   ADJR_I2  1592-1594       ADJR_I3  1595-1597       ADJR_IHI  1598-1600   
   ADJR_J1  1601-1603       ADJR_J2  1604-1606       ADJR_J3  1607-1609    
   ADJR_JHI  1610-1612      ADJR_K1  1613-1615       ADJR_K2  1616-1618    
   ADJR_K3  1619-1621       ADJR_KHI  1622-1624      ADJR_L1  1625-1627    
   ADJR_L2  1628-1630       ADJR_L3  1631-1633       ADJR_LHI  1634-1636   
   ADJR_M1  1637-1639       ADJR_M2  1640-1642       ADJR_M3  1643-1645    
   ADJR_MHI  1646-1648      ADJR_N1  1649-1651       ADJR_N2  1652-1654    
   ADJR_N3  1655-1657       ADJR_NHI  1658-1660      ADJR_O1  1661-1663    
   ADJR_O2  1664-1666       ADJR_O3  1667-1669       ADJR_OHI  1670-1672   
   ADJR_P1  1673-1675       ADJR_P2  1676-1678       ADJR_P3  1679-1681    
   ADJR_PHI  1682-1684      ADJR_Q1  1685-1687       ADJR_Q2  1688-1690    
   ADJR_Q3  1691-1693       ADJR_QHI  1694-1696      ADJR_R1  1697-1699    
   ADJR_R2  1700-1702       ADJR_R3  1703-1705       ADJR_RHI  1706-1708   
   ADJR_S1  1709-1711       ADJR_S2  1712-1714       ADJR_S3  1715-1717    
   ADJR_SHI  1718-1720      ADJR_T1  1721-1723       ADJR_T2  1724-1726    
   ADJR_T3  1727-1729       ADJR_THI  1730-1732      ADJR_U1  1733-1735    
   ADJR_U2  1736-1738       ADJR_U3  1739-1741       ADJR_UHI  1742-1744   
   BASADR1  1745-1747       BASADR2  1748-1750       BASADR3  1751-1753    
   BASADRHI  1754-1756      BASER1  1757-1759        BASER2  1760-1762     
   BASER3  1763-1765        BASERHI  1766-1768       BASLNR1  1769-1771    
   BASLNR2  1772-1774       BASLNR3  1775-1777       BASLNRHI  1778-1780   
   ADJOFC1  1781-1783       ADJOFC2  1784-1786       ADJOFC3  1787-1789    
   ADJOFCHI  1790-1792      ADJC_B1  1793-1795       ADJC_B2  1796-1798    
   ADJC_B3  1799-1801       ADJC_BHI  1802-1804      ADJC_C1  1805-1807    
   ADJC_C2  1808-1810       ADJC_C3  1811-1813       ADJC_CHI  1814-1816   
   ADJC_D1  1817-1819       ADJC_D2  1820-1822       ADJC_D3  1823-1825    
   ADJC_DHI  1826-1828      ADJC_E1  1829-1831       ADJC_E2  1832-1834    
   ADJC_E3  1835-1837       ADJC_EHI  1838-1840      ADJC_F1  1841-1843    
   ADJC_F2  1844-1846       ADJC_F3  1847-1849       ADJC_FHI  1850-1852   
   ADJC_G1  1853-1855       ADJC_G2  1856-1858       ADJC_G3  1859-1861    
   ADJC_GHI  1862-1864      ADJC_H1  1865-1867       ADJC_H2  1868-1870    
   ADJC_H3  1871-1873       ADJC_HHI  1874-1876      ADJC_I1  1877-1879    
   ADJC_I2  1880-1882       ADJC_I3  1883-1885       ADJC_IHI  1886-1888   
   ADJC_J1  1889-1891       ADJC_J2  1892-1894       ADJC_J3  1895-1897    
   ADJC_JHI  1898-1900      ADJC_K1  1901-1903       ADJC_K2  1904-1906    
   ADJC_K3  1907-1909       ADJC_KHI  1910-1912      ADJC_L1  1913-1915    
   ADJC_L2  1916-1918       ADJC_L3  1919-1921       ADJC_LHI  1922-1924   
   ADJC_M1  1925-1927       ADJC_M2  1928-1930       ADJC_M3  1931-1933    
   ADJC_MHI  1934-1936      ADJC_N1  1937-1939       ADJC_N2  1940-1942    
   ADJC_N3  1943-1945       ADJC_NHI  1946-1948      ADJC_O1  1949-1951    
   ADJC_O2  1952-1954       ADJC_O3  1955-1957       ADJC_OHI  1958-1960   
   ADJC_P1  1961-1963       ADJC_P2  1964-1966       ADJC_P3  1967-1969    
   ADJC_PHI  1970-1972      ADJC_Q1  1973-1975       ADJC_Q2  1976-1978    
   ADJC_Q3  1979-1981       ADJC_QHI  1982-1984      ADJC_R1  1985-1987    
   ADJC_R2  1988-1990       ADJC_R3  1991-1993       ADJC_RHI  1994-1996   
   ADJC_S1  1997-1999       ADJC_S2  2000-2002       ADJC_S3  2003-2005    
   ADJC_SHI  2006-2008      ADJC_T1  2009-2011       ADJC_T2  2012-2014    
   ADJC_T3  2015-2017       ADJC_THI  2018-2020      ADJC_U1  2021-2023    
   ADJC_U2  2024-2026       ADJC_U3  2027-2029       ADJC_UHI  2030-2032   
   BASADC1  2033-2035       BASADC2  2036-2038       BASADC3  2039-2041    
   BASADCHI  2042-2044      BASEC1  2045-2047        BASEC2  2048-2050     
   BASEC3  2051-2053        BASECHI  2054-2056       BASLNC1  2057-2059    
   BASLNC2  2060-2062       BASLNC3  2063-2065       BASLNCHI  2066-2068   
   ADJOFU1  2069-2071       ADJOFU2  2072-2074       ADJOFU3  2075-2077    
   ADJOFUHI  2078-2080      ADJU_B1  2081-2083       ADJU_B2  2084-2086    
   ADJU_B3  2087-2089       ADJU_BHI  2090-2092      ADJU_C1  2093-2095    
   ADJU_C2  2096-2098       ADJU_C3  2099-2101       ADJU_CHI  2102-2104   
   ADJU_D1  2105-2107       ADJU_D2  2108-2110       ADJU_D3  2111-2113    
   ADJU_DHI  2114-2116      ADJU_E1  2117-2119       ADJU_E2  2120-2122    
   ADJU_E3  2123-2125       ADJU_EHI  2126-2128      ADJU_F1  2129-2131    
   ADJU_F2  2132-2134       ADJU_F3  2135-2137       ADJU_FHI  2138-2140   
   ADJU_G1  2141-2143       ADJU_G2  2144-2146       ADJU_G3  2147-2149    
   ADJU_GHI  2150-2152      ADJU_H1  2153-2155       ADJU_H2  2156-2158    
   ADJU_H3  2159-2161       ADJU_HHI  2162-2164      ADJU_I1  2165-2167    
   ADJU_I2  2168-2170       ADJU_I3  2171-2173       ADJU_IHI  2174-2176   
   ADJU_J1  2177-2179       ADJU_J2  2180-2182       ADJU_J3  2183-2185    
   ADJU_JHI  2186-2188      ADJU_K1  2189-2191       ADJU_K2  2192-2194    
   ADJU_K3  2195-2197       ADJU_KHI  2198-2200      ADJU_L1  2201-2203    
   ADJU_L2  2204-2206       ADJU_L3  2207-2209       ADJU_LHI  2210-2212   
   ADJU_M1  2213-2215       ADJU_M2  2216-2218       ADJU_M3  2219-2221    
   ADJU_MHI  2222-2224      ADJU_N1  2225-2227       ADJU_N2  2228-2230    
   ADJU_N3  2231-2233       ADJU_NHI  2234-2236      ADJU_O1  2237-2239    
   ADJU_O2  2240-2242       ADJU_O3  2243-2245       ADJU_OHI  2246-2248   
   ADJU_P1  2249-2251       ADJU_P2  2252-2254       ADJU_P3  2255-2257    
   ADJU_PHI  2258-2260      ADJU_Q1  2261-2263       ADJU_Q2  2264-2266    
   ADJU_Q3  2267-2269       ADJU_QHI  2270-2272      ADJU_R1  2273-2275    
   ADJU_R2  2276-2278       ADJU_R3  2279-2281       ADJU_RHI  2282-2284   
   ADJU_S1  2285-2287       ADJU_S2  2288-2290       ADJU_S3  2291-2293    
   ADJU_SHI  2294-2296      ADJU_T1  2297-2299       ADJU_T2  2300-2302    
   ADJU_T3  2303-2305       ADJU_THI  2306-2308      ADJU_U1  2309-2311    
   ADJU_U2  2312-2314       ADJU_U3  2315-2317       ADJU_UHI  2318-2320   
   BASADU1  2321-2323       BASADU2  2324-2326       BASADU3  2327-2329    
   BASADUHI  2330-2332      BASEU1  2333-2335        BASEU2  2336-2338     
   BASEU3  2339-2341        BASEUHI  2342-2344       BASLNU1  2345-2347    
   BASLNU2  2348-2350       BASLNU3  2351-2353       BASLNUHI  2354-2356   
   ADJL_B1 $ 2357           ADJL_B2 $ 2358           ADJL_B3 $ 2359        
   ADJL_BHI $ 2360          ADJL_C1 $ 2361-2362      ADJL_C2 $ 2363        
   ADJL_C3 $ 2364           ADJL_CHI $ 2365-2366     ADJL_D1 $ 2367        
   ADJL_D2 $ 2368           ADJL_D3 $ 2369           ADJL_DHI $ 2370       
   ADJL_E1 $ 2371           ADJL_E2 $ 2372           ADJL_E3 $ 2373        
   ADJL_EHI $ 2374          ADJL_F1 $ 2375           ADJL_F2 $ 2376        
   ADJL_F3 $ 2377           ADJL_FHI $ 2378          ADJL_G1 $ 2379        
   ADJL_G2 $ 2380           ADJL_G3 $ 2381           ADJL_GHI $ 2382       
   ADJL_H1 $ 2383-2384      ADJL_H2 $ 2385           ADJL_H3 $ 2386        
   ADJL_HHI $ 2387-2388     ADJL_I1 $ 2389           ADJL_I2 $ 2390        
   ADJL_I3 $ 2391           ADJL_IHI $ 2392          ADJL_J1 $ 2393        
   ADJL_J2 $ 2394           ADJL_J3 $ 2395           ADJL_JHI $ 2396       
   ADJL_K1 $ 2397           ADJL_K2 $ 2398           ADJL_K3 $ 2399        
   ADJL_KHI $ 2400          ADJL_L1 $ 2401           ADJL_L2 $ 2402        
   ADJL_L3 $ 2403           ADJL_LHI $ 2404          ADJL_M1 $ 2405        
   ADJL_M2 $ 2406           ADJL_M3 $ 2407           ADJL_MHI $ 2408       
   ADJL_N1 $ 2409           ADJL_N2 $ 2410           ADJL_N3 $ 2411        
   ADJL_NHI $ 2412          ADJL_O1 $ 2413           ADJL_O2 $ 2414        
   ADJL_O3 $ 2415           ADJL_OHI $ 2416          ADJL_P1 $ 2417        
   ADJL_P2 $ 2418           ADJL_P3 $ 2419           ADJL_PHI $ 2420       
   ADJL_Q1 $ 2421           ADJL_Q2 $ 2422           ADJL_Q3 $ 2423        
   ADJL_QHI $ 2424          ADJL_R1 $ 2425           ADJL_R2 $ 2426        
   ADJL_R3 $ 2427           ADJL_RHI $ 2428          ADJL_S1 $ 2429        
   ADJL_S2 $ 2430           ADJL_S3 $ 2431           ADJL_SHI $ 2432       
   ADJL_T1 $ 2433           ADJL_T2 $ 2434           ADJL_T3 $ 2435        
   ADJL_THI $ 2436          ADJL_U1 $ 2437-2438      ADJL_U2 $ 2439        
   ADJL_U3 $ 2440           ADJL_UHI $ 2441-2442     BASEL1 $ 2443         
   BASEL2 $ 2444            BASEL3 $ 2445            BASELHI $ 2446        
   ADSL_B1 $ 2447           ADSL_B2 $ 2448           ADSL_B3 $ 2449        
   ADSL_BHI $ 2450          ADSL_C1 $ 2451-2452      ADSL_C2 $ 2453        
   ADSL_C3 $ 2454           ADSL_CHI $ 2455-2456     ADSL_D1 $ 2457        
   ADSL_D2 $ 2458           ADSL_D3 $ 2459           ADSL_DHI $ 2460       
   ADSL_E1 $ 2461           ADSL_E2 $ 2462           ADSL_E3 $ 2463        
   ADSL_EHI $ 2464          ADSL_F1 $ 2465           ADSL_F2 $ 2466        
   ADSL_F3 $ 2467           ADSL_FHI $ 2468          ADSL_G1 $ 2469        
   ADSL_G2 $ 2470           ADSL_G3 $ 2471           ADSL_GHI $ 2472       
   ADSL_H1 $ 2473-2474      ADSL_H2 $ 2475           ADSL_H3 $ 2476        
   ADSL_HHI $ 2477-2478     ADSL_I1 $ 2479           ADSL_I2 $ 2480        
   ADSL_I3 $ 2481           ADSL_IHI $ 2482          ADSL_J1 $ 2483        
   ADSL_J2 $ 2484           ADSL_J3 $ 2485           ADSL_JHI $ 2486       
   ADSL_K1 $ 2487           ADSL_K2 $ 2488           ADSL_K3 $ 2489        
   ADSL_KHI $ 2490          ADSL_L1 $ 2491           ADSL_L2 $ 2492        
   ADSL_L3 $ 2493           ADSL_LHI $ 2494          ADSL_M1 $ 2495        
   ADSL_M2 $ 2496           ADSL_M3 $ 2497           ADSL_MHI $ 2498       
   ADSL_N1 $ 2499           ADSL_N2 $ 2500           ADSL_N3 $ 2501        
   ADSL_NHI $ 2502          ADSL_O1 $ 2503           ADSL_O2 $ 2504        
   ADSL_O3 $ 2505           ADSL_OHI $ 2506          ADSL_P1 $ 2507        
   ADSL_P2 $ 2508           ADSL_P3 $ 2509           ADSL_PHI $ 2510       
   ADSL_Q1 $ 2511           ADSL_Q2 $ 2512           ADSL_Q3 $ 2513        
   ADSL_QHI $ 2514          ADSL_R1 $ 2515           ADSL_R2 $ 2516        
   ADSL_R3 $ 2517           ADSL_RHI $ 2518          ADSL_S1 $ 2519        
   ADSL_S2 $ 2520           ADSL_S3 $ 2521           ADSL_SHI $ 2522       
   ADSL_T1 $ 2523           ADSL_T2 $ 2524           ADSL_T3 $ 2525        
   ADSL_THI $ 2526          ADSL_U1 $ 2527-2528      ADSL_U2 $ 2529        
   ADSL_U3 $ 2530           ADSL_UHI $ 2531-2532     BASESL1 $ 2533        
   BASESL2 $ 2534           BASESL3 $ 2535           BASESLHI $ 2536       
   ADRL_B1 $ 2537           ADRL_B2 $ 2538           ADRL_B3 $ 2539        
   ADRL_BHI $ 2540          ADRL_C1 $ 2541-2542      ADRL_C2 $ 2543        
   ADRL_C3 $ 2544           ADRL_CHI $ 2545-2546     ADRL_D1 $ 2547        
   ADRL_D2 $ 2548           ADRL_D3 $ 2549           ADRL_DHI $ 2550       
   ADRL_E1 $ 2551           ADRL_E2 $ 2552           ADRL_E3 $ 2553        
   ADRL_EHI $ 2554          ADRL_F1 $ 2555           ADRL_F2 $ 2556        
   ADRL_F3 $ 2557           ADRL_FHI $ 2558          ADRL_G1 $ 2559        
   ADRL_G2 $ 2560           ADRL_G3 $ 2561           ADRL_GHI $ 2562       
   ADRL_H1 $ 2563           ADRL_H2 $ 2564           ADRL_H3 $ 2565        
   ADRL_HHI $ 2566          ADRL_I1 $ 2567           ADRL_I2 $ 2568        
   ADRL_I3 $ 2569           ADRL_IHI $ 2570          ADRL_J1 $ 2571        
   ADRL_J2 $ 2572           ADRL_J3 $ 2573           ADRL_JHI $ 2574       
   ADRL_K1 $ 2575           ADRL_K2 $ 2576           ADRL_K3 $ 2577        
   ADRL_KHI $ 2578          ADRL_L1 $ 2579           ADRL_L2 $ 2580        
   ADRL_L3 $ 2581           ADRL_LHI $ 2582          ADRL_M1 $ 2583        
   ADRL_M2 $ 2584           ADRL_M3 $ 2585           ADRL_MHI $ 2586       
   ADRL_N1 $ 2587           ADRL_N2 $ 2588           ADRL_N3 $ 2589        
   ADRL_NHI $ 2590          ADRL_O1 $ 2591           ADRL_O2 $ 2592        
   ADRL_O3 $ 2593           ADRL_OHI $ 2594          ADRL_P1 $ 2595        
   ADRL_P2 $ 2596           ADRL_P3 $ 2597           ADRL_PHI $ 2598       
   ADRL_Q1 $ 2599           ADRL_Q2 $ 2600           ADRL_Q3 $ 2601        
   ADRL_QHI $ 2602          ADRL_R1 $ 2603           ADRL_R2 $ 2604        
   ADRL_R3 $ 2605           ADRL_RHI $ 2606          ADRL_S1 $ 2607        
   ADRL_S2 $ 2608           ADRL_S3 $ 2609           ADRL_SHI $ 2610       
   ADRL_T1 $ 2611           ADRL_T2 $ 2612           ADRL_T3 $ 2613        
   ADRL_THI $ 2614          ADRL_U1 $ 2615           ADRL_U2 $ 2616        
   ADRL_U3 $ 2617           ADRL_UHI $ 2618          BASERL1 $ 2619        
   BASERL2 $ 2620           BASERL3 $ 2621           BASERLHI $ 2622       
   ADCL_B1 $ 2623           ADCL_B2 $ 2624           ADCL_B3 $ 2625        
   ADCL_BHI $ 2626          ADCL_C1 $ 2627           ADCL_C2 $ 2628        
   ADCL_C3 $ 2629           ADCL_CHI $ 2630          ADCL_D1 $ 2631        
   ADCL_D2 $ 2632           ADCL_D3 $ 2633           ADCL_DHI $ 2634       
   ADCL_E1 $ 2635           ADCL_E2 $ 2636           ADCL_E3 $ 2637        
   ADCL_EHI $ 2638          ADCL_F1 $ 2639           ADCL_F2 $ 2640        
   ADCL_F3 $ 2641           ADCL_FHI $ 2642          ADCL_G1 $ 2643        
   ADCL_G2 $ 2644           ADCL_G3 $ 2645           ADCL_GHI $ 2646       
   ADCL_H1 $ 2647           ADCL_H2 $ 2648           ADCL_H3 $ 2649        
   ADCL_HHI $ 2650          ADCL_I1 $ 2651           ADCL_I2 $ 2652        
   ADCL_I3 $ 2653           ADCL_IHI $ 2654          ADCL_J1 $ 2655        
   ADCL_J2 $ 2656           ADCL_J3 $ 2657           ADCL_JHI $ 2658       
   ADCL_K1 $ 2659           ADCL_K2 $ 2660           ADCL_K3 $ 2661        
   ADCL_KHI $ 2662          ADCL_L1 $ 2663           ADCL_L2 $ 2664        
   ADCL_L3 $ 2665           ADCL_LHI $ 2666          ADCL_M1 $ 2667        
   ADCL_M2 $ 2668           ADCL_M3 $ 2669           ADCL_MHI $ 2670       
   ADCL_N1 $ 2671           ADCL_N2 $ 2672           ADCL_N3 $ 2673        
   ADCL_NHI $ 2674          ADCL_O1 $ 2675           ADCL_O2 $ 2676        
   ADCL_O3 $ 2677           ADCL_OHI $ 2678          ADCL_P1 $ 2679        
   ADCL_P2 $ 2680           ADCL_P3 $ 2681           ADCL_PHI $ 2682       
   ADCL_Q1 $ 2683           ADCL_Q2 $ 2684           ADCL_Q3 $ 2685        
   ADCL_QHI $ 2686          ADCL_R1 $ 2687           ADCL_R2 $ 2688        
   ADCL_R3 $ 2689           ADCL_RHI $ 2690          ADCL_S1 $ 2691        
   ADCL_S2 $ 2692           ADCL_S3 $ 2693           ADCL_SHI $ 2694       
   ADCL_T1 $ 2695           ADCL_T2 $ 2696           ADCL_T3 $ 2697        
   ADCL_THI $ 2698          ADCL_U1 $ 2699           ADCL_U2 $ 2700        
   ADCL_U3 $ 2701           ADCL_UHI $ 2702          BASECL1 $ 2703        
   BASECL2 $ 2704           BASECL3 $ 2705           BASECLHI $ 2706       
   ADUL_B1 $ 2707           ADUL_B2 $ 2708           ADUL_B3 $ 2709        
   ADUL_BHI $ 2710          ADUL_C1 $ 2711           ADUL_C2 $ 2712        
   ADUL_C3 $ 2713           ADUL_CHI $ 2714          ADUL_D1 $ 2715        
   ADUL_D2 $ 2716           ADUL_D3 $ 2717           ADUL_DHI $ 2718       
   ADUL_E1 $ 2719           ADUL_E2 $ 2720           ADUL_E3 $ 2721        
   ADUL_EHI $ 2722          ADUL_F1 $ 2723           ADUL_F2 $ 2724        
   ADUL_F3 $ 2725           ADUL_FHI $ 2726          ADUL_G1 $ 2727        
   ADUL_G2 $ 2728           ADUL_G3 $ 2729           ADUL_GHI $ 2730       
   ADUL_H1 $ 2731           ADUL_H2 $ 2732           ADUL_H3 $ 2733        
   ADUL_HHI $ 2734          ADUL_I1 $ 2735           ADUL_I2 $ 2736        
   ADUL_I3 $ 2737           ADUL_IHI $ 2738          ADUL_J1 $ 2739        
   ADUL_J2 $ 2740           ADUL_J3 $ 2741           ADUL_JHI $ 2742       
   ADUL_K1 $ 2743           ADUL_K2 $ 2744           ADUL_K3 $ 2745        
   ADUL_KHI $ 2746          ADUL_L1 $ 2747           ADUL_L2 $ 2748        
   ADUL_L3 $ 2749           ADUL_LHI $ 2750          ADUL_M1 $ 2751        
   ADUL_M2 $ 2752           ADUL_M3 $ 2753           ADUL_MHI $ 2754       
   ADUL_N1 $ 2755           ADUL_N2 $ 2756           ADUL_N3 $ 2757        
   ADUL_NHI $ 2758          ADUL_O1 $ 2759           ADUL_O2 $ 2760        
   ADUL_O3 $ 2761           ADUL_OHI $ 2762          ADUL_P1 $ 2763        
   ADUL_P2 $ 2764           ADUL_P3 $ 2765           ADUL_PHI $ 2766       
   ADUL_Q1 $ 2767           ADUL_Q2 $ 2768           ADUL_Q3 $ 2769        
   ADUL_QHI $ 2770          ADUL_R1 $ 2771           ADUL_R2 $ 2772        
   ADUL_R3 $ 2773           ADUL_RHI $ 2774          ADUL_S1 $ 2775        
   ADUL_S2 $ 2776           ADUL_S3 $ 2777           ADUL_SHI $ 2778       
   ADUL_T1 $ 2779           ADUL_T2 $ 2780           ADUL_T3 $ 2781        
   ADUL_THI $ 2782          ADUL_U1 $ 2783           ADUL_U2 $ 2784        
   ADUL_U3 $ 2785           ADUL_UHI $ 2786          BASEUL1 $ 2787        
   BASEUL2 $ 2788           BASEUL3 $ 2789           BASEULHI $ 2790       
   GDLINE1 $ 2791-2795      GDLINE2 $ 2796-2800      GDLINE3 $ 2801-2805   
   GDSTAT1 $ 2806-2810      GDSTAT2 $ 2811-2815      GDSTAT3 $ 2816-2820   
   GDREF1 $ 2821-2825       GDREF2 $ 2826            GDREF3 $ 2827         
   GDCROS1 $ 2828           GDCROS2 $ 2829           GDCROS3 $ 2830        
   GDUNDR1 $ 2831           GDUNDR2 $ 2832           GDUNDR3 $ 2833        
   GDLINEHI $ 2834-2838     GDSTATHI $ 2839-2843     GDREFHI $ 2844-2848   
   GDCROSHI $ 2849          GDUNDRHI $ 2850          STA1_1 $ 2851-2861    
   STA1_2 $ 2862-2870       STA1_3 $ 2871-2878       STA1_4 $ 2879-2886    
   STA1_5 $ 2887-2894       STA1_6 $ 2895-2902       STA1_7 $ 2903-2909    
   STA1_8 $ 2910-2915       STA1_9 $ 2916-2921       STA1_10 $ 2922-2927   
   STA1_11 $ 2928-2933      STA1_12 $ 2934-2939      STA1_13 $ 2940-2945   
   STA1_14 $ 2946-2951      STA1_15 $ 2952-2957      STA1_16 $ 2958-2963   
   STA1_17 $ 2964-2969      STA1_18 $ 2970-2975      STA1_19 $ 2976-2981   
   STA1_20 $ 2982-2987      STA1_21 $ 2988-2993      STA1_22 $ 2994-2999   
   STA1_23 $ 3000-3005      STA1_24 $ 3006-3011      STA1_25 $ 3012-3017   
   STA1_26 $ 3018-3023      STA1_27 $ 3024-3029      STA1_28 $ 3030-3035   
   STA1_29 $ 3036-3041      STA1_30 $ 3042-3047      STA1_31 $ 3048-3055   
   STA1_32 $ 3056-3063      STA1_33 $ 3064-3071      STA1_34 $ 3072-3079   
   STA1_35 $ 3080-3087      STA1_36 $ 3088-3095      STA2_1 $ 3096-3106    
   STA2_2 $ 3107-3116       STA2_3 $ 3117-3126       STA2_4 $ 3127-3135    
   STA2_5 $ 3136-3144       STA2_6 $ 3145-3153       STA2_7 $ 3154-3162    
   STA2_8 $ 3163-3171       STA2_9 $ 3172-3180       STA2_10 $ 3181-3189   
   STA2_11 $ 3190-3198      STA2_12 $ 3199-3207      STA2_13 $ 3208-3216   
   STA2_14 $ 3217-3225      STA2_15 $ 3226-3234      STA2_16 $ 3235-3243   
   STA2_17 $ 3244-3252      STA2_18 $ 3253-3261      STA2_19 $ 3262-3270   
   STA2_20 $ 3271-3279      STA2_21 $ 3280-3288      STA2_22 $ 3289-3297   
   STA2_23 $ 3298-3306      STA2_24 $ 3307-3315      STA2_25 $ 3316-3324   
   STA2_26 $ 3325-3333      STA2_27 $ 3334-3342      STA2_28 $ 3343-3351   
   STA2_29 $ 3352-3360      STA2_30 $ 3361-3369      STA2_31 $ 3370-3373   
   STA2_32 $ 3374           STA2_33 $ 3375           STA2_34 $ 3376        
   STA2_35 $ 3377           STA2_36 $ 3378           STA3_1 $ 3379-3387    
   STA3_2 $ 3388-3395       STA3_3 $ 3396-3403       STA3_4 $ 3404         
   STA3_5 $ 3405            STA3_6 $ 3406            STA3_7 $ 3407         
   STA3_8 $ 3408-3413       STA3_9 $ 3414            STA3_10 $ 3415        
   STA3_11 $ 3416           STA3_12 $ 3417           STA3_13 $ 3418        
   STA3_14 $ 3419           STA3_15 $ 3420           STA3_16 $ 3421        
   STA3_17 $ 3422           STA3_18 $ 3423           STA3_19 $ 3424        
   STA3_20 $ 3425           STA3_21 $ 3426           STA3_22 $ 3427        
   STA3_23 $ 3428           STA3_24 $ 3429           STA3_25 $ 3430        
   STA3_26 $ 3431           STA3_27 $ 3432           STA3_28 $ 3433        
   STA3_29 $ 3434           STA3_30 $ 3435           STA3_31 $ 3436        
   STA3_32 $ 3437           STA3_33 $ 3438           STA3_34 $ 3439        
   STA3_35 $ 3440           STA3_36 $ 3441           NWSTAT1 $ 3442-3452   
   NWSTAT2 $ 3453-3463      NWSTAT3 $ 3464-3473      NWSTAT4 $ 3474-3483   
   NWSTAT5 $ 3484-3492      NWSTAT6 $ 3493-3502      NWSTAT7 $ 3503-3508   
   NWSTAT8 $ 3509-3516      NWSTAT9 $ 3517-3524      TTSC1_1 $ 3525-3531   
   TTSC1_2 $ 3532-3538      TTSC1_3 $ 3539-3544      TTSC1_4 $ 3545-3550   
   TTSC1_5 $ 3551-3556      TTSC1_6 $ 3557-3562      TTSC1_7 $ 3563-3568   
   TTSC1_8 $ 3569-3574      TTSC1_9 $ 3575-3580      TTSC1_10 $ 3581-3586  
   TTSC1_11 $ 3587-3592     TTSC1_12 $ 3593-3598     TTSC1_13 $ 3599-3604  
   TTSC1_14 $ 3605-3610     TTSC1_15 $ 3611-3616     TTSC1_16 $ 3617-3622  
   TTSC1_17 $ 3623-3628     TTSC1_18 $ 3629-3634     TTSC1_19 $ 3635-3640  
   TTSC1_20 $ 3641-3646     TTSC1_21 $ 3647-3652     TTSC1_22 $ 3653-3658  
   TTSC1_23 $ 3659-3664     TTSC1_24 $ 3665-3670     TTSC1_25 $ 3671-3676  
   TTSC1_26 $ 3677-3682     TTSC1_27 $ 3683-3688     TTSC1_28 $ 3689-3694  
   TTSC1_29 $ 3695-3700     TTSC1_30 $ 3701-3706     TTSC1_31 $ 3707-3712  
   TTSC1_32 $ 3713-3718     TTSC1_33 $ 3719-3724     TTSC1_34 $ 3725-3730  
   TTSC1_35 $ 3731-3736     TTSC1_36 $ 3737-3742     TTSC2_1 $ 3743-3748   
   TTSC2_2 $ 3749-3754      TTSC2_3 $ 3755-3760      TTSC2_4 $ 3761-3766   
   TTSC2_5 $ 3767-3772      TTSC2_6 $ 3773-3778      TTSC2_7 $ 3779-3784   
   TTSC2_8 $ 3785-3790      TTSC2_9 $ 3791-3796      TTSC2_10 $ 3797-3802  
   TTSC2_11 $ 3803-3808     TTSC2_12 $ 3809-3814     TTSC2_13 $ 3815-3820  
   TTSC2_14 $ 3821-3826     TTSC2_15 $ 3827-3832     TTSC2_16 $ 3833-3838  
   TTSC2_17 $ 3839-3844     TTSC2_18 $ 3845-3850     TTSC2_19 $ 3851-3856  
   TTSC2_20 $ 3857-3862     TTSC2_21 $ 3863-3868     TTSC2_22 $ 3869-3874  
   TTSC2_23 $ 3875-3880     TTSC2_24 $ 3881-3886     TTSC2_25 $ 3887-3892  
   TTSC2_26 $ 3893-3898     TTSC2_27 $ 3899-3904     TTSC2_28 $ 3905-3910  
   TTSC2_29 $ 3911-3916     TTSC2_30 $ 3917-3922     TTSC2_31 $ 3923-3925  
   TTSC2_32 $ 3926          TTSC2_33 $ 3927          TTSC2_34 $ 3928       
   TTSC2_35 $ 3929          TTSC2_36 $ 3930          TTSC3_1 $ 3931-3936   
   TTSC3_2 $ 3937-3942      TTSC3_3 $ 3943-3948      TTSC3_4 $ 3949        
   TTSC3_5 $ 3950           TTSC3_6 $ 3951           TTSC3_7 $ 3952        
   TTSC3_8 $ 3953-3958      TTSC3_9 $ 3959           TTSC3_10 $ 3960       
   TTSC3_11 $ 3961          TTSC3_12 $ 3962          TTSC3_13 $ 3963       
   TTSC3_14 $ 3964          TTSC3_15 $ 3965          TTSC3_16 $ 3966       
   TTSC3_17 $ 3967          TTSC3_18 $ 3968          TTSC3_19 $ 3969       
   TTSC3_20 $ 3970          TTSC3_21 $ 3971          TTSC3_22 $ 3972       
   TTSC3_23 $ 3973          TTSC3_24 $ 3974          TTSC3_25 $ 3975       
   TTSC3_26 $ 3976          TTSC3_27 $ 3977          TTSC3_28 $ 3978       
   TTSC3_29 $ 3979          TTSC3_30 $ 3980          TTSC3_31 $ 3981       
   TTSC3_32 $ 3982          TTSC3_33 $ 3983          TTSC3_34 $ 3984       
   TTSC3_35 $ 3985          TTSC3_36 $ 3986          SMAX1  3987-3995      
   SMAX2  3996-4003         SMAX3  4004-4011         SMAX4  4012-4019      
   SMAX5  4020-4027         SMAX6  4028-4035         SMAX7  4036-4043      
   SMAX8  4044-4051         SMAX9  4052-4059         SMAX10  4060-4067     
   SMAX11  4068-4075        SMAX12  4076-4083        SMAX13  4084-4091     
   SMAX14  4092-4099        SMAX15  4100-4107        SMAX16  4108-4115     
   SMAX17  4116-4123        SMAX18  4124-4131        SMAX19  4132-4139     
   SMAX20  4140-4147        SMAX21  4148-4155        SMAX22  4156-4163     
   SMAX23  4164-4171        SMAX24  4172-4179        SMAX25  4180-4187     
   SMAX26  4188-4195        SMAX27  4196-4203        SMAX28  4204-4211     
   SMAX29  4212-4219        SMAX30  4220-4227        SMAX31  4228-4235     
   SMAX32  4236-4243        SMAX33  4244-4251        SMAX34  4252-4259     
   SMAX35  4260-4267        SMAX36  4268-4275        SMIN1  4276-4283      
   SMIN2  4284-4291         SMIN3  4292-4299         SMIN4  4300-4307      
   SMIN5  4308-4315         SMIN6  4316-4323         SMIN7  4324-4331      
   SMIN8  4332-4339         SMIN9  4340-4347         SMIN10  4348-4355     
   SMIN11  4356-4363        SMIN12  4364-4371        SMIN13  4372-4379     
   SMIN14  4380-4387        SMIN15  4388-4395        SMIN16  4396-4403     
   SMIN17  4404-4411        SMIN18  4412-4419        SMIN19  4420-4427     
   SMIN20  4428-4435        SMIN21  4436-4443        SMIN22  4444-4451     
   SMIN23  4452-4459        SMIN24  4460-4467        SMIN25  4468-4475     
   SMIN26  4476-4483        SMIN27  4484-4491        SMIN28  4492-4499     
   SMIN29  4500-4507        SMIN30  4508-4515        SMIN31  4516-4523     
   SMIN32  4524-4531        SMIN33  4532-4539        SMIN34  4540-4547     
   SMIN35  4548-4555        SMIN36  4556-4563        RETEXT1 $ 4564-4603   
   RETEXT2 $ 4604           RETEXT3 $ 4605           RETEXT4 $ 4606        
   RETEXT5 $ 4607         ;                       

LENGTH
   ACCEPT 3                 BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                OWNSTRCT 3               PLEA 3                
   PRIMOFF 3                PRCIVIL 3                PRCRIME 3             
   PROBATN 3                PROBMON 3                PSR 3                 
   QUARTER 3                REAS1 4                  REAS2 4               
   REAS3 4                  REAS4 4                  REAS5 4               
   REASON2 3                REASON3 3                REASON4 3             
   REASONS 3                REMEDORD 3               SELFREP 3             
   SENTRNGE 3               TOLERNCE 3               TYPEOTHS 3            
   VICTNOTE 3               VIOLATE 3                AMENDYR 4             
   SENTYR 4                 COSTASSM 4               DISGORGE 6            
   FINOFFST 6               FORFEITR 6               STATMIN 3             
   STATMAX 6                RESTCAT 3                FINECAT 3             
   SUSFNCAT 3               LCAT1 3                  LCAT2 3               
   LCAT3 3                  LCATHI 3                 LCATS1 3              
   LCATS2 3                 LCATS3 3                 LCATSHI 3             
   LCATR1 3                 LCATR2 3                 LCATR3 3              
   LCATRHI 3                LCATC1 3                 LCATC2 3              
   LCATC3 3                 LCATCHI 3                LCATU1 3              
   LCATU2 3                 LCATU3 3                 LCATUHI 3             
   CPIDN 6                  ADJOFL1 3                ADJOFL2 3             
   ADJOFL3 3                ADJOFLHI 3               ADJ_B1 3              
   ADJ_B2 3                 ADJ_B3 3                 ADJ_BHI 3             
   ADJ_C1 3                 ADJ_C2 3                 ADJ_C3 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_D3 3                 ADJ_DHI 3                ADJ_E1 3              
   ADJ_E2 3                 ADJ_E3 3                 ADJ_EHI 3             
   ADJ_F1 3                 ADJ_F2 3                 ADJ_F3 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_G3 3                 ADJ_GHI 3                ADJ_H1 3              
   ADJ_H2 3                 ADJ_H3 3                 ADJ_HHI 3             
   ADJ_I1 3                 ADJ_I2 3                 ADJ_I3 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_J3 3                 ADJ_JHI 3                ADJ_K1 3              
   ADJ_K2 3                 ADJ_K3 3                 ADJ_KHI 3             
   ADJ_L1 3                 ADJ_L2 3                 ADJ_L3 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_M3 3                 ADJ_MHI 3                ADJ_N1 3              
   ADJ_N2 3                 ADJ_N3 3                 ADJ_NHI 3             
   ADJ_O1 3                 ADJ_O2 3                 ADJ_O3 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_P3 3                 ADJ_PHI 3                ADJ_Q1 3              
   ADJ_Q2 3                 ADJ_Q3 3                 ADJ_QHI 3             
   ADJ_R1 3                 ADJ_R2 3                 ADJ_R3 3              
   ADJ_RHI 3                ADJ_S1 3                 ADJ_S2 3              
   ADJ_S3 3                 ADJ_SHI 3                ADJ_T1 3              
   ADJ_T2 3                 ADJ_T3 3                 ADJ_THI 3             
   ADJ_U1 3                 ADJ_U2 3                 ADJ_U3 3              
   ADJ_UHI 3                BASADJ1 3                BASADJ2 3             
   BASADJ3 3                BASADJHI 3               BASE1 3               
   BASE2 3                  BASE3 3                  BASEHI 3              
   BASLN1 3                 BASLN2 3                 BASLN3 3              
   BASLNHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFS3 3                ADJOFSHI 3               ADJS_B1 3             
   ADJS_B2 3                ADJS_B3 3                ADJS_BHI 3            
   ADJS_C1 3                ADJS_C2 3                ADJS_C3 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_D3 3                ADJS_DHI 3               ADJS_E1 3             
   ADJS_E2 3                ADJS_E3 3                ADJS_EHI 3            
   ADJS_F1 3                ADJS_F2 3                ADJS_F3 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_G3 3                ADJS_GHI 3               ADJS_H1 3             
   ADJS_H2 3                ADJS_H3 3                ADJS_HHI 3            
   ADJS_I1 3                ADJS_I2 3                ADJS_I3 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_J3 3                ADJS_JHI 3               ADJS_K1 3             
   ADJS_K2 3                ADJS_K3 3                ADJS_KHI 3            
   ADJS_L1 3                ADJS_L2 3                ADJS_L3 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_M3 3                ADJS_MHI 3               ADJS_N1 3             
   ADJS_N2 3                ADJS_N3 3                ADJS_NHI 3            
   ADJS_O1 3                ADJS_O2 3                ADJS_O3 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_P3 3                ADJS_PHI 3               ADJS_Q1 3             
   ADJS_Q2 3                ADJS_Q3 3                ADJS_QHI 3            
   ADJS_R1 3                ADJS_R2 3                ADJS_R3 3             
   ADJS_RHI 3               ADJS_S1 3                ADJS_S2 3             
   ADJS_S3 3                ADJS_SHI 3               ADJS_T1 3             
   ADJS_T2 3                ADJS_T3 3                ADJS_THI 3            
   ADJS_U1 3                ADJS_U2 3                ADJS_U3 3             
   ADJS_UHI 3               BASADS1 3                BASADS2 3             
   BASADS3 3                BASADSHI 3               BASES1 3              
   BASES2 3                 BASES3 3                 BASESHI 3             
   BASLNS1 3                BASLNS2 3                BASLNS3 3             
   BASLNSHI 3               ADJOFR1 3                ADJOFR2 3             
   ADJOFR3 3                ADJOFRHI 3               ADJR_B1 3             
   ADJR_B2 3                ADJR_B3 3                ADJR_BHI 3            
   ADJR_C1 3                ADJR_C2 3                ADJR_C3 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_D3 3                ADJR_DHI 3               ADJR_E1 3             
   ADJR_E2 3                ADJR_E3 3                ADJR_EHI 3            
   ADJR_F1 3                ADJR_F2 3                ADJR_F3 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_G3 3                ADJR_GHI 3               ADJR_H1 3             
   ADJR_H2 3                ADJR_H3 3                ADJR_HHI 3            
   ADJR_I1 3                ADJR_I2 3                ADJR_I3 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_J3 3                ADJR_JHI 3               ADJR_K1 3             
   ADJR_K2 3                ADJR_K3 3                ADJR_KHI 3            
   ADJR_L1 3                ADJR_L2 3                ADJR_L3 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_M3 3                ADJR_MHI 3               ADJR_N1 3             
   ADJR_N2 3                ADJR_N3 3                ADJR_NHI 3            
   ADJR_O1 3                ADJR_O2 3                ADJR_O3 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_P3 3                ADJR_PHI 3               ADJR_Q1 3             
   ADJR_Q2 3                ADJR_Q3 3                ADJR_QHI 3            
   ADJR_R1 3                ADJR_R2 3                ADJR_R3 3             
   ADJR_RHI 3               ADJR_S1 3                ADJR_S2 3             
   ADJR_S3 3                ADJR_SHI 3               ADJR_T1 3             
   ADJR_T2 3                ADJR_T3 3                ADJR_THI 3            
   ADJR_U1 3                ADJR_U2 3                ADJR_U3 3             
   ADJR_UHI 3               BASADR1 3                BASADR2 3             
   BASADR3 3                BASADRHI 3               BASER1 3              
   BASER2 3                 BASER3 3                 BASERHI 3             
   BASLNR1 3                BASLNR2 3                BASLNR3 3             
   BASLNRHI 3               ADJOFC1 3                ADJOFC2 3             
   ADJOFC3 3                ADJOFCHI 3               ADJC_B1 3             
   ADJC_B2 3                ADJC_B3 3                ADJC_BHI 3            
   ADJC_C1 3                ADJC_C2 3                ADJC_C3 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_D3 3                ADJC_DHI 3               ADJC_E1 3             
   ADJC_E2 3                ADJC_E3 3                ADJC_EHI 3            
   ADJC_F1 3                ADJC_F2 3                ADJC_F3 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_G3 3                ADJC_GHI 3               ADJC_H1 3             
   ADJC_H2 3                ADJC_H3 3                ADJC_HHI 3            
   ADJC_I1 3                ADJC_I2 3                ADJC_I3 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_J3 3                ADJC_JHI 3               ADJC_K1 3             
   ADJC_K2 3                ADJC_K3 3                ADJC_KHI 3            
   ADJC_L1 3                ADJC_L2 3                ADJC_L3 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_M3 3                ADJC_MHI 3               ADJC_N1 3             
   ADJC_N2 3                ADJC_N3 3                ADJC_NHI 3            
   ADJC_O1 3                ADJC_O2 3                ADJC_O3 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_P3 3                ADJC_PHI 3               ADJC_Q1 3             
   ADJC_Q2 3                ADJC_Q3 3                ADJC_QHI 3            
   ADJC_R1 3                ADJC_R2 3                ADJC_R3 3             
   ADJC_RHI 3               ADJC_S1 3                ADJC_S2 3             
   ADJC_S3 3                ADJC_SHI 3               ADJC_T1 3             
   ADJC_T2 3                ADJC_T3 3                ADJC_THI 3            
   ADJC_U1 3                ADJC_U2 3                ADJC_U3 3             
   ADJC_UHI 3               BASADC1 3                BASADC2 3             
   BASADC3 3                BASADCHI 3               BASEC1 3              
   BASEC2 3                 BASEC3 3                 BASECHI 3             
   BASLNC1 3                BASLNC2 3                BASLNC3 3             
   BASLNCHI 3               ADJOFU1 3                ADJOFU2 3             
   ADJOFU3 3                ADJOFUHI 3               ADJU_B1 3             
   ADJU_B2 3                ADJU_B3 3                ADJU_BHI 3            
   ADJU_C1 3                ADJU_C2 3                ADJU_C3 3             
   ADJU_CHI 3               ADJU_D1 3                ADJU_D2 3             
   ADJU_D3 3                ADJU_DHI 3               ADJU_E1 3             
   ADJU_E2 3                ADJU_E3 3                ADJU_EHI 3            
   ADJU_F1 3                ADJU_F2 3                ADJU_F3 3             
   ADJU_FHI 3               ADJU_G1 3                ADJU_G2 3             
   ADJU_G3 3                ADJU_GHI 3               ADJU_H1 3             
   ADJU_H2 3                ADJU_H3 3                ADJU_HHI 3            
   ADJU_I1 3                ADJU_I2 3                ADJU_I3 3             
   ADJU_IHI 3               ADJU_J1 3                ADJU_J2 3             
   ADJU_J3 3                ADJU_JHI 3               ADJU_K1 3             
   ADJU_K2 3                ADJU_K3 3                ADJU_KHI 3            
   ADJU_L1 3                ADJU_L2 3                ADJU_L3 3             
   ADJU_LHI 3               ADJU_M1 3                ADJU_M2 3             
   ADJU_M3 3                ADJU_MHI 3               ADJU_N1 3             
   ADJU_N2 3                ADJU_N3 3                ADJU_NHI 3            
   ADJU_O1 3                ADJU_O2 3                ADJU_O3 3             
   ADJU_OHI 3               ADJU_P1 3                ADJU_P2 3             
   ADJU_P3 3                ADJU_PHI 3               ADJU_Q1 3             
   ADJU_Q2 3                ADJU_Q3 3                ADJU_QHI 3            
   ADJU_R1 3                ADJU_R2 3                ADJU_R3 3             
   ADJU_RHI 3               ADJU_S1 3                ADJU_S2 3             
   ADJU_S3 3                ADJU_SHI 3               ADJU_T1 3             
   ADJU_T2 3                ADJU_T3 3                ADJU_THI 3            
   ADJU_U1 3                ADJU_U2 3                ADJU_U3 3             
   ADJU_UHI 3               BASADU1 3                BASADU2 3             
   BASADU3 3                BASADUHI 3               BASEU1 3              
   BASEU2 3                 BASEU3 3                 BASEUHI 3             
   BASLNU1 3                BASLNU2 3                BASLNU3 3             
   BASLNUHI 3               SMAX1 6                  SMAX2 6               
   SMAX3 6                  SMAX4 6                  SMAX5 6               
   SMAX6 6                  SMAX7 6                  SMAX8 6               
   SMAX9 6                  SMAX10 6                 SMAX11 6              
   SMAX12 6                 SMAX13 6                 SMAX14 6              
   SMAX15 6                 SMAX16 6                 SMAX17 6              
   SMAX18 6                 SMAX19 6                 SMAX20 6              
   SMAX21 6                 SMAX22 6                 SMAX23 6              
   SMAX24 6                 SMAX25 6                 SMAX26 6              
   SMAX27 6                 SMAX28 6                 SMAX29 6              
   SMAX30 6                 SMAX31 6                 SMAX32 6              
   SMAX33 6                 SMAX34 6                 SMAX35 6              
   SMAX36 6                 SMIN1 3                  SMIN2 3               
   SMIN3 3                  SMIN4 3                  SMIN5 3               
   SMIN6 3                  SMIN7 3                  SMIN8 3               
   SMIN9 3                  SMIN10 3                 SMIN11 3              
   SMIN12 3                 SMIN13 3                 SMIN14 3              
   SMIN15 3                 SMIN16 3                 SMIN17 3              
   SMIN18 3                 SMIN19 3                 SMIN20 3              
   SMIN21 3                 SMIN22 3                 SMIN23 3              
   SMIN24 3                 SMIN25 3                 SMIN26 3              
   SMIN27 3                 SMIN28 3                 SMIN29 3              
   SMIN30 3                 SMIN31 3                 SMIN32 3              
   SMIN33 3                 SMIN34 3                 SMIN35 3              
   SMIN36 3 ;

          

RUN ;
